@@ -240,11 +240,7 @@ fn draw_containers_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect
         Cell::from(c.ready.to_owned()),
         Cell::from(c.status.to_owned()),
         Cell::from(c.restarts.to_string()),
-        Cell::from(format!(
-          "{}/{}",
-          c.liveliness_probe.to_string(),
-          c.readiness_probe.to_string()
-        )),
+        Cell::from(format!("{}/{}", c.liveliness_probe, c.readiness_probe,)),
         Cell::from(c.ports.to_owned()),
         Cell::from(c.age.to_owned()),
       ])
@@ -954,7 +950,7 @@ struct ResourceTableProps<'a, T> {
   column_widths: Vec<Constraint>,
 }
 
-/// Draw a kubernetes resource i overview tab
+/// Draw a kubernetes resource overview tab
 fn draw_resource_block<'a, B, T, F>(
   f: &mut Frame<B>,
   area: Rect,
@@ -993,7 +989,7 @@ fn draw_resource_block<'a, B, T, F>(
 fn get_resource_row_style(status: &str, ready: (i32, i32)) -> Style {
   if status == "Running" && ready.0 == ready.1 {
     style_primary()
-  } else if status == "Completed" && ready.0 == ready.1 {
+  } else if status == "Completed" {
     style_success()
   } else if [
     "ContainerCreating",
